Skip to contents

Called automatically by the grid graphics system when a tfl_table_grob is rendered. Not intended to be called directly.

Usage

# S3 method for class 'tfl_table_grob'
drawDetails(x, recording)

Arguments

x

A tfl_table_grob object.

recording

Logical; passed by grid (not used directly).

Value

Called for its side effect of drawing the table.