Specify how strings are broken when wrapping table text
wrap_breaks.RdA wrap_breaks object lists the characters at which .wrap_string() is
allowed to insert a line break. Two modes are supported:
Details
dropcharacters are consumed at the break point. The default (" "and"\t") means runs of whitespace disappear when a wrap occurs there but stay inline otherwise.keep_beforecharacters stay on the left of the break - the character is preserved at the end of the upper line and the next character starts the new line. Typical use:"-"so that a hyphenated term like"placebo-controlled"can wrap to"placebo-\ncontrolled".
drop and keep_before must be disjoint single-character vectors.